==> gottet_1.1.9.orig.tar.gz: gottet-1.1.9/translations/gottet_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>질문 있습니다</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>하고 계신 게임을 끝내실 건가요?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;잠시멈춤&lt;/b&gt;&lt;/big&gt;&lt;br&gt;계속하시려면 화면을 클릭하세요.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;게임 오버!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;화면을 클릭하시면 새 게임을 시작합니다.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>프로그램 언어 선택</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>시스템 언어</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>노트</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>바꾸신 언어 설정을 적용하시려면 프로그램을 다시 시작해 주세요</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>고테트 득점표</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>레벨</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>줄</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>점수</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>고테트</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>새 게임을 시작하려면 클릭하세요.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;게임</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;새 게임</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;잠시 멈춤</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;계속하기</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;점수판</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;끝내기</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;설정</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>사용할 언어</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;도움말</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;고테트란</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt에 관해</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>다음 블록</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>레벨</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>깬 줄 수</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>점수</translation>
    </message>
    <message>
        <source>About</source>
        <translation>고테트란</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>아내를 위해 만든 테트리스 복제 게임입니다.</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;GPL 3&lt;/a&gt; 라이선스에 따라 배포됩니다.</translation>
    </message>
</context>
</TS>

==> gottet_1.2.4.orig.tar.gz: gottet-1.2.4/translations/gottet_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>질문 있습니다</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>하고 계신 게임을 끝내실 건가요?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;잠시멈춤&lt;/b&gt;&lt;/big&gt;&lt;br&gt;계속하시려면 화면을 클릭하세요.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;게임 오버!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;화면을 클릭하시면 새 게임을 시작합니다.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>프로그램 언어 선택</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>시스템 언어</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>노트</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>바꾸신 언어 설정을 적용하시려면 프로그램을 다시 시작해 주세요</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>레벨</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>줄</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>점수</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>고테트</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>새 게임을 시작하려면 클릭하세요.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;게임</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;새 게임</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;잠시 멈춤</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;점수판</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;끝내기</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;설정</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>사용할 언어</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;도움말</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;고테트란</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt에 관해</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>다음 블록</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>레벨</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>깬 줄 수</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>점수</translation>
    </message>
    <message>
        <source>About</source>
        <translation>고테트란</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;GPL 3&lt;/a&gt; 라이선스에 따라 배포됩니다.</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
